==> trade-center-biz-0.2.2-ZDX-20161103.125609-1-sources.jar: cn/com/duiba/order/center/biz/remoteservice/RemoteAmbSubOrdersServiceImpl.java <==
package cn.com.duiba.order.center.biz.remoteservice;

import cn.com.duiba.order.center.api.dto.AmbSubOrdersDto;
import cn.com.duiba.order.center.api.remoteservice.RemoteAmbSubOrdersService;
import cn.com.duiba.order.center.biz.service.credits.AmbSubOrdersService;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Created by yansen on 16/9/26.
 */
@Service
public class RemoteAmbSubOrdersServiceImpl implements RemoteAmbSubOrdersService {
    @Autowired
    private AmbSubOrdersService ambSubOrdersService;
    @Override
    public DubboResult<Integer> updateSettleStatusWaitSettleBySubId(Long subId) {
        return DubboResult.successResult(ambSubOrdersService.updateSettleStatusWaitSettleBySubId(subId));
    }

    @Override
    public DubboResult<AmbSubOrdersDto> findSubOrderById(Long subId) {
        return DubboResult.successResult(ambSubOrdersService.findSubOrderById(subId));
    }

    @Override
    public DubboResult<Integer> updateSettleStatusSettleBySubId(Long subId) {
        return DubboResult.successResult(ambSubOrdersService.updateSettleStatusSettleBySubId(subId));
    }

    @Override
    public DubboResult<Integer> updateRemarkBySubId(Long subId, String remark) {
        return DubboResult.successResult(ambSubOrdersService.updateRemarkBySubId(subId,remark));
    }

    @Override
    public DubboResult<Integer>  updateSettleStatusNoneBySubId(Long subId, Long consumerPayBackPrice) {
        return DubboResult.successResult(ambSubOrdersService.updateSettleStatusNoneBySubId(subId, consumerPayBackPrice));
    }

    @Override
    public DubboResult<Integer> updateShipStatus4ReceivedAtCreate(Long subId) {
        return DubboResult.successResult(ambSubOrdersService.updateShipStatus4ReceivedAtCreate(subId));
    }
}

==> trade-center-biz-0.5.4-ZDX-20161221.123948-1-sources.jar: cn/com/duiba/order/center/biz/remoteservice/RemoteAmbSubOrdersServiceImpl.java <==
package cn.com.duiba.order.center.biz.remoteservice;

import cn.com.duiba.order.center.api.dto.AmbSubOrdersDto;
import cn.com.duiba.order.center.api.remoteservice.RemoteAmbSubOrdersService;
import cn.com.duiba.order.center.biz.service.credits.AmbSubOrdersService;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Created by yansen on 16/9/26.
 */
@Service
public class RemoteAmbSubOrdersServiceImpl implements RemoteAmbSubOrdersService {
    @Autowired
    private AmbSubOrdersService ambSubOrdersService;
    @Override
    public DubboResult<Integer> updateSettleStatusWaitSettleBySubId(Long subId) {
        return DubboResult.successResult(ambSubOrdersService.updateSettleStatusWaitSettleBySubId(subId));
    }

    @Override
    public DubboResult<AmbSubOrdersDto> findSubOrderById(Long subId) {
        return DubboResult.successResult(ambSubOrdersService.findSubOrderById(subId));
    }

    @Override
    public DubboResult<Integer> updateSettleStatusSettleBySubId(Long subId) {
        return DubboResult.successResult(ambSubOrdersService.updateSettleStatusSettleBySubId(subId));
    }

    @Override
    public DubboResult<Integer> updateRemarkBySubId(Long subId, String remark) {
        return DubboResult.successResult(ambSubOrdersService.updateRemarkBySubId(subId,remark));
    }

    @Override
    public DubboResult<Integer>  updateSettleStatusNoneBySubId(Long subId, Long consumerPayBackPrice) {
        return DubboResult.successResult(ambSubOrdersService.updateSettleStatusNoneBySubId(subId, consumerPayBackPrice));
    }

    @Override
    public DubboResult<Integer> updateShipStatus4ReceivedAtCreate(Long subId) {
        return DubboResult.successResult(ambSubOrdersService.updateShipStatus4ReceivedAtCreate(subId));
    }

    @Override
    public DubboResult<Integer> updateShipStatus4WaitShip(Long subId){
        return DubboResult.successResult(ambSubOrdersService.updateShipStatus4WaitShip(subId));
    }

    @Override
    public DubboResult<Integer> updateShipStatus4Shiped(Long subId){
        return DubboResult.successResult(ambSubOrdersService.updateShipStatus4Shiped(subId));
    }
}
